/* vi:set wm=0 ai tabstop=4 shiftwidth=4: */

/*
 * sctl - Bearcat scanner control program
 * Copyright (C) 2001 Ian Johnston <reaper@muppetlabs.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

#ifndef _COMMANDS_H_
#define _COMMANDS_H_

extern int scannermodel;

/***********************************************************************
 * config for scanner commands, etc.
 ***********************************************************************/

/***********************************************************************
 * keycodes for the KEY command
 ***********************************************************************/

#define K_SCAN			"KEY00"		/* SCAN */
#define K_MANUAL		"KEY01"		/* MAN (manual) */
#define K_0				"KEY02 0"	/* numeric keypad key 0 */
#define K_1				"KEY02 1"	/* numeric keypad key 1 */
#define K_2				"KEY02 2"	/* numeric keypad key 2 */
#define K_3				"KEY02 3"	/* numeric keypad key 3 */
#define K_4				"KEY02 4"	/* numeric keypad key 4 */
#define K_5				"KEY02 5"	/* numeric keypad key 5 */
#define K_6				"KEY02 6"	/* numeric keypad key 6 */
#define K_7				"KEY02 7"	/* numeric keypad key 7 */
#define K_8				"KEY02 8"	/* numeric keypad key 8 */
#define K_9				"KEY02 9"	/* numeric keypad key 9 */
#define K_DOT			"KEY03"		/* "." (decimal point) and [245][2052][780] ATT (attenuator) */
#define K_ENTER			"KEY04"		/* E (enter) [780] Key04H - Release Remote Control */
#define K_PRI			"KEY05"		/* PRI (priority) */
#define K_LO			"KEY06"		/* L/O (lockout) */
#define K_HOLD_UP		"KEY07"		/* HOLD/UP (arrow) */
#define K_LIMIT_DN		"KEY08"		/* LIMIT/DOWN (arrow) */
#define K_SRC			"KEY09"		/* SRCH (search) */
#define K_WX			"KEY10"		/* [895] [780] Weather [245] [2052] SVC Search */
#define K_DATA			"KEY11"		/* [895][245][2052] DATA [780] Menu */
#define K_DELAY			"KEY12"		/* [895][245][2052] DLY (delay) [780] Select [780] Key12H - Mute On */
#define K_TRUNK			"KEY13"		/* TRUNK */
#define K_DIM			"KEY14"		/* [895] Dim toggle [245] * (lightbulb) [2052] Shift [780] VFO Push Button */
#define K_STEP			"KEY15"		/* [895] Step */
#define K_AUX			"KEY16"		/* [895] Aux */
#define K_ALERT_REMOTE	"KEY17"		/* [895] Alert/Remote */
#define K_SEND			"KEY18"		/* [895] Send */
#define K_AUTO			"KEY19"		/* [895] Auto */
#define K_CTCSS			"KEY20"		/* [895] Ctcss */
#define K_A				"KEY21 A"	/* [895] A */
#define K_B				"KEY21 B"	/* [895] B */
#define K_C				"KEY21 C"	/* [895] C */
#define K_D				"KEY21 D"	/* [895] D */
#define K_E				"KEY21 E"	/* [895] E */
#define K_F				"KEY21 F"	/* [895] F */
#define K_G				"KEY21 G"	/* [895] G */
#define K_H				"KEY21 H"	/* [895] H */
#define K_I				"KEY21 I"	/* [895] I */
#define K_J				"KEY21 J"	/* [895] J */
#define K_FREQ_CHAN		"KEY22"		/* [895] Freq/Chan toggle */
#define K_LOCK			"KEY23"		/* [895] Lock */

/***********************************************************************
 * mode codes  (NOT raw modes!)
 ***********************************************************************/

#define M_CHAN_SCAN			0	/* conventional channel scan mode */
#define M_MANUAL			1	/* manual mode */
#define M_LIMIT_SRCH		2	/* limit search mode */
#define M_LIMIT_SRCH_HOLD	3	/* limit search hold mode */
#define M_WX_SCAN			4	/* 895/780 weather scan mode */
#define M_WX_SCAN_HOLD		5	/* 895/780 weather scan hold mode */
#define M_SVC_SCAN			6	/* 245/2052 service scan mode */
#define M_SVC_SCAN_HOLD		7	/* 245/2052 service scan hold mode */
#define M_M_PGM_TRUNK		8	/* motorola program trunk frequency mode */
#define M_E_PGM_TRUNK		9	/* 245/2052 edacs program trunk frequency mode */
#define M_TRUNK_PGM			10	/* 245/2052 trunk system program mode */
#define M_M_ID_SRCH			11	/* motorola id search mode */
#define M_M_ID_SRCH_HOLD	12	/* motorola id search hold mode */
#define M_M_ID_SCAN			13	/* motorola id scan mode */
#define M_M_ID_MANUAL		14	/* motorola id manual mode */
#define M_M_ID_LO			15	/* motorola id lockout review mode */
#define M_M_SRCH_CCHAN		16	/* motorola search control channel mode */
#define M_E_ID_SRCH			17	/* 245/2052 edacs id search mode */
#define M_E_ID_SRCH_HOLD	18	/* 245/2052 edacs id search hold mode */
#define M_E_ID_SCAN			19	/* 245/2052 edacs id scan mode */
#define M_E_ID_MANUAL		20	/* 245/2052 edacs id manual mode */
#define M_E_ID_LO			21	/* 245/2052 edacs id lockout review mode */
#define M_E_SRCH_CCHAN		22	/* 245/2052 edacs search control channel mode */
#define M_ROT_TUNE			23	/* 895/780 rotary tuned frequency mode */
#define M_PGM_CTCSS			24	/* 895 program ctcss mode */
#define M_WX_ALERT			25	/* 895 weather alert mode */
#define M_FREQ_SEND			26	/* 895 frequency send mode */
#define M_AUTO_STORE		27	/* 895 auto store mode */
#define M_RF_TUNE			28	/* 245/2052 rf tune mode */
#define M_UNKNOWN			29	/* unknown mode */

/***********************************************************************
 * function declarations
 ***********************************************************************/

int att(int fd, int att_var);
int data(int fd, int data_var);
int delay(int fd, int delay_var);
int dump(int fd, char bank, FILE *outfile);
int get_mode(int fd);
int get_mode_raw(int fd);
int id_report(int fd);
int light(int fd, int light);
int limit(int fd, int query, double freq1, double freq2);
int load(int fd, char bank, FILE *infile);
int lockout(int fd, int lockout_var, int force);
int mem(int fd, int channel, double freq, int force, int set);
int mute(int fd, int mute_var);
int press_key(int fd, char *key);
int scan(int fd, char *banks);
int scan_report(int fd, char *banks);
int scan_trunk(int fd, char *banks);
int search(int fd);
int set_mode(int fd, int mode_var, char bank);
int set_scan_banks(int fd, char *banks);
int talkgroup(int fd, char *memloc, int groupid, char bank);
int talkgroup_all(int fd, char bank);
int version(int fd);

#endif /* _COMMANDS_H_ */
